cocos.gl_framebuffer_object module — cocos v0.6.10 documentation

# cocos.gl_framebuffer_object module

A thin wrapper for OpenGL framebuffer objets. For implementation use only

class `FramebufferObject`

  Bases: `object`

  Wrapper for framebuffer objects. See

  http://oss.sgi.com/projects/ogl-sample/registry/EXT/framebuffer_object.txt

  API is not very OO, should be improved.

  `bind`()

    Set FBO as current rendering target

  `check_status`()

    Check that currently set framebuffer is ready for rendering

  `texture2d`(texture)

    Map currently bound framebuffer (not necessarily self) to texture

  `unbind`()

    Set default framebuffer as current rendering target